.. _wb_sample:

Sample Workbench Example
===============================================================================

Here is the Python entry point for the example (:download:`download here
<../../../examples/workbench/sample.py>`):

.. literalinclude:: ../../../examples/workbench/sample.py
    :language: python

The resulting GUI looks like this (on Ubuntu):

.. image:: images/wb_main.png

There are three workspaces available in the dropdown menu, which are loaded 
just prior to display.

.. image:: images/wb_first.png

.. image:: images/wb_second.png

.. image:: images/wb_third.png
